/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl.db;


import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

import com.topcoder.db.connectionfactory.DBConnectionFactory;
import com.topcoder.db.connectionfactory.DBConnectionFactoryImpl;

/**
 * A helper class providing a lot of database operations.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
final class DatabaseHelper {

    /**
     * The namespace for test.
     */
    private static final String NAMESPACE = "com.topcoder.document.index.persistence.impl.db.unittest";

    /**
     * The DBConnectionFactory instance to create connections.
     */
    private static DBConnectionFactory connectionFactory = null;

    /**
     * Private constructor.
     */
    private DatabaseHelper() {
        // empty
    }

    /**
     * Gets a connection.
     * @return a connection
     * @throws Exception to JUnit
     */
    public static Connection createConnection() throws Exception  {

        if (connectionFactory == null) {
            connectionFactory = new DBConnectionFactoryImpl(NAMESPACE);
        }

        return connectionFactory.createConnection();
    }

    /**
     * Execute the given sql update command.
     * @param commad the command
     * @throws Exception to JUnit
     */
    public static void executeUpdate(String command) throws Exception {
        Connection conn = null;
        PreparedStatement ps = null;
        ResultSet rs = null;

        try {

            conn = createConnection();
            ps = conn.prepareStatement(command);
            ps.executeUpdate();

        } finally {
            dispose(conn, ps, rs);
        }
    }


    /**
     * Clears given table.
     * @param tableName the table to clear
     * @throws Exception to JUnit
     */
    public static void clearTable(String tableName) throws Exception {
        executeUpdate("DELETE FROM " + tableName);
    }




    /**
     * Dispose JDBC resources.
     *
     * @param conn the connection.
     * @param ps the prepared statement.
     * @param rs the result set.
     */
    public static void dispose(Connection conn, PreparedStatement ps, ResultSet rs) {
        if (rs != null) {
            try {
                rs.close();
            } catch (Exception e) {
            }
        }
        if (ps != null) {
            try {
                ps.close();
            } catch (Exception e) {
            }
        }
        if (conn != null) {
            try {
                conn.close();
            } catch (Exception e) {
            }
        }
    }
}
